@@ -1,17 +1,19 @@
 from django import forms
 
+
 class ImageForm(forms.Form):
     image = forms.ImageField()
     description = forms.CharField(
         required=False,
         widget=forms.TextInput(attrs={
             'class': 'form-control',
-            'placeholder': 'a short description of the image for screen readers and search engines',
+            'placeholder': 'a short description of the image for screen ' +
+            'readers and search engines',
         })
     )
     size = forms.ChoiceField(
-        widget = forms.RadioSelect,
-        choices = (
+        widget=forms.RadioSelect,
+        choices=(
             ('Billboard', 'Billboard'),
             ('Small', 'Small'),
             ('Medium', 'Medium'),
@@ -19,4 +21,4 @@ class ImageForm(forms.Form):
             ('Original', 'Original'),
         ),
         initial = 'Billboard'
-    )
\ No newline at end of file
+    )
